@@ -28,7 +28,7 @@ dependencies using raw pip. The virtual environment is not created, but one can
 issue `python3 -m venv venv/ && . venv/bin/activate` to create one.
 """
 
-__version__ = "1.3.0"
+__version__ = "1.3.1"
 __author__ = "Fridolin Pokorny <fridex.devel@gmail.com>"
 __title__ = "micropipenv"
 
@@ -48,7 +48,7 @@ from pathlib import Path
 from urllib.parse import urlparse
 
 _LOGGER = logging.getLogger(__title__)
-_SUPPORTED_PIP_STR = ">=9,<=22.0.4"  # Respects requirement in setup.py and latest pip to release date.
+_SUPPORTED_PIP_STR = ">=9,<=22.1.2"  # Respects requirement in setup.py and latest pip to release date.
 
 try:
     from pip import __version__ as pip_version
@@ -1108,8 +1108,14 @@ def _get_package_entry_str(
 
         if "ref" in info:
             result += "@{}".format(info["ref"])
-        result += "#egg={}\n".format(package_name)
-        return result
+        result += "#egg={}".format(package_name)
+
+        # The URL might contain a subdirectory like:
+        # git+ssh://git@github.com/RidgeRun/gstd-1.x.git@v0.13.2#egg=pygstc\&subdirectory=libgstc/python
+        if "subdirectory" in info:
+            result += "&subdirectory={}".format(info["subdirectory"])
+
+        return "\n" + result
     if "path" in info:
         # Path formats we want to support:
         # - "file:///path/to/project"
